@@ -2,10 +2,10 @@
 # You may use and distribute this software under the terms of the
 # GNU General Public License, version 2 or later
 
-cvs_id = "$Id: __init__.py,v 1.59 2003/11/30 00:49:34 juri Exp $"
+cvs_id = "$Id: __init__.py,v 1.2 2004/04/16 20:26:07 jpakaste Exp $"
 
 APPNAME = "Straw"
-VERSION = "0.22.1"
+VERSION = "0.23"
 STRAW_URL = "http://www.nongnu.org/straw/"
 STRAW_REF_URL = "%sstraw-ref.html" % STRAW_URL
 
