@@ -64,11 +64,11 @@ def convert_entities(text):
         ent_code = entities.get(ents[1:-1], None)
         if ent_code is not None:
             try:
-                ents = unicode(ent_code, get_locale(enc=True))
+                ents = unicode(ent_code, get_locale_encoding())
             except UnicodeDecodeError:
                 ents = unicode(ent_code, 'latin-1')
             except Exception, ex:
-                error.log("%s -- %s" % (ex, ents))
+                error.log("error occurred while converting entity %s: %s" % (ents, ex))
 
             # check if it still needs conversion
             if entity.search(ents) is None:
@@ -108,41 +108,38 @@ def get_url_location(url):
     parsed_url = urlparse.urlsplit(url)
     return urlparse.urlunsplit((parsed_url[0], parsed_url[1], '','',''))
 
-def get_locale(lang=False, enc=False):
-    default = ('en_US', 'ISO8859-1')
-
+def get_locale_lang():
     try:
         language, encoding = locale.getlocale(locale.LC_MESSAGES)
-    except (ValueError, Exception):
-        return default
+    except (ValueError, Exception), ex:
+        error.log("%s" % ex)
 
     if language is not None:
-        # only setlocale uses this atm. extend when needed.
-        language = locale.normalize(language)
-
-
-    if lang:
-        return language
-    elif enc:
-        if (encoding is not None) and (encoding != ''):
-            return encoding
-        else:
-            return 'ISO8859-1'
+        return locale.normalize(language)
     else:
-        return (language, encoding)
+        # default
+        return 'en_US'
 
+def get_locale_encoding():
+    try:
+        language, encoding = locale.getlocale(locale.LC_MESSAGES)
+    except (ValueError, Exception), ex:
+        error.log("%s" % ex)
+
+    if encoding is not None and encoding != '':
+        return locale.normalize(encoding)
+    else:
+        return 'ISO8859-1'
 
 weekday = ["Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun"]
 months = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"]
 
 def format_date(date, format, encoding):
-    try:
-        timestr = time.strftime(format, time.localtime(calendar.timegm(date)))
-    except Exception, ex:
-        #time is time.struct_time
-        timestr = "%s, %02d %s %02d:%02d" % (weekday[date.tm_wday], date.tm_mday,
-                                             months[date.tm_mon - 1],
-                                             date.tm_hour, date.tm_min)
+    timestr = time.strftime(format, time.localtime(calendar.timegm(date)))
+    #time is time.struct_time
+    #timestr = "%s, %02d %s %02d:%02d" % (weekday[date.tm_wday], date.tm_mday,
+                                         #months[date.tm_mon - 1],
+                                         #date.tm_hour, date.tm_min)
 
     return unicode(timestr, encoding)
 
@@ -153,7 +150,7 @@ def convert_title(title, description = ''):
             if len(description):
                 title = read_text(description, MAX_DISPLAY_CHAR) + '...'
         except TypeError:
-            error.log("description is unsized")
+            error.log("empty title and description, leave as is...")
             # no title, no description, leave it.
             return
 
